function SetModify() 

	-- ignore existing part.

	local create = Byte.create;
	Byte.create = function(size)
		local str = {};
		str.value = string.rep(string.char(0), size);
		return str;
	end

	local bloadfile = Byte.loadfile;
	Byte.loadfile = function(b,filename,start,length)
		local INF = assert(io.open(filename, "rb"));
		local _;
		_, b.value = INF:read(start, length);
		io.close(INF);
	end

	local savefile = Byte.savefile;
	Byte.savefile = function(b,filename,start,length)
		local INF = assert(io.open(filename, "rb"));
		local _previous, _, _next  = INF:read(start, length, "*all");
		io.close(INF);
		INF = assert(io.open(filename, "wb"));
		INF:write(_previous or "", b.value , string.rep(string.char(0), length - string.len(b.value)), _next or "");
		io.close(INF);
	end

	local cache = {};
	local getnum = function(b,start, size, unsign)
		local str = string.sub(b.value, start + 1, start + size);
		if not cache[str] then
			local sum = 0
			for i = size, 1, -1 do
				sum = sum * 256 + string.byte(str, i)
			end
			-- test for negative number
			if not unsign and string.byte(str, size) > 127 then
				sum = sum - math.ldexp(1, 8 * size)
			end
			cache[str] = sum;
		end
		return cache[str];
	end
	
	local setnum = function(b,start,va, size, unsign)
		local v = ""
		local x = math.floor(va);
		if unsign or x >= 0 then
			for i = 1, size do
				v = v..string.char(x % 256); x = math.floor(x / 256)
			end
		else-- x < 0
			x = -x
			local carry = 1
			for i = 1, size do
				local c = 255 - (x % 256) + carry
				if c == 256 then c = 0; carry = 1 else carry = 0 end
				v = v..string.char(c); x = math.floor(x / 256)
			end
		end
		b.value = string.sub(b.value, 1,  start).. v ..string.sub(b.value, start + size + 1)
	end

	local get16 = Byte.get16;
	Byte.get16 = function(b,start)
		return getnum(b,start,2);
	end

	local set16 = Byte.set16;
	Byte.set16 = function(b,start,v)
		setnum(b,start,v, 2);
	end

	local getu16 = Byte.getu16;
	Byte.getu16 = function(b,start)
		return getnum(b,start,2, true);
	end

	local setu16 = Byte.setu16;
	Byte.setu16 = function(b,start,v)
		setnum(b,start,v, 2, true);
	end
  
	local get32 = Byte.get32;
	Byte.get32 = function(b,start)
		return getnum(b,start,4);
	end

	local set32 = Byte.set32;
	Byte.set32 = function(b,start,v)
		setnum(b,start,v, 4);
	end
   
    local getstr = Byte.getstr;
	Byte.getstr = function(b,start,length)
		return string.sub(b.value,start + 1, start + length);
	end

    local setstr = Byte.setstr;
	Byte.setstr = function(b,start,length,str)
		b.value = string.sub(b.value, 1,  start).. string.sub(str, 1,  length) ..string.sub(b.value, start + length + 1)
	end

	
end

Byte = Byte or {};

ok, msg = pcall(SetModify)
if not ok then
  print(msg)
else
	local int,nint,uint,long,str,filename = 2341,-122, 65278,285212671,"Wo shi 10C", "filename";
	local data=Byte.create(20);
	Byte.set16(data, 0, int);
	Byte.set16(data, 2, nint);
	Byte.setu16(data, 4, uint);
	Byte.set32(data, 6, long);
	Byte.setstr(data, 10, 10, str);
	Byte.savefile(data,filename,0,20);

	local datar=Byte.create(20);
	Byte.loadfile(datar,filename,0,20);
	print("1=" , Byte.get16(datar,0), (Byte.get16(datar,0) == int and "  matched") or " not matched");
	print("2=" , Byte.get16(datar,2), (Byte.get16(datar,2) == nint and "  matched") or " not matched");
	print("3=" , Byte.getu16(datar,4), (Byte.getu16(datar,4) == uint and "  matched") or " not matched");
	print("4=" , Byte.get32(datar,6), (Byte.get32(datar,6) == long and "  matched") or " not matched");
	print("5=" , Byte.getstr(datar,10, 10), (Byte.getstr(datar,10,10) == str and "  matched") or " not matched");
end
